rad:z3gqcJUoA1n9HaHKufZs5FCSGazv5 heartwoodd8e5a19cd61da43640b61bb7487ced0f63f0c6f4
{
"request": "trigger",
"version": 1,
"event_type": "patch",
"repository": {
"id": "rad:z3gqcJUoA1n9HaHKufZs5FCSGazv5",
"name": "heartwood",
"description": "Radicle Heartwood Protocol & Stack",
"private": false,
"default_branch": "master",
"delegates": [
"did:key:z6MksFqXN3Yhqk8pTJdUGLwATkRfQvwZXPqR2qMEhbS9wzpT",
"did:key:z6MktaNvN1KVFMkSRAiN4qK5yvX1zuEEaseeX5sffhzPZRZW",
"did:key:z6MkireRatUThvd3qzfKht1S44wpm4FEWSSa4PRMTSQZ3voM",
"did:key:z6MkgFq6z5fkF2hioLLSNu1zP2qEL1aHXHZzGH1FLFGAnBGz",
"did:key:z6MkkPvBfjP4bQmco5Dm7UGsX2ruDBieEHi8n9DVJWX5sTEz"
]
},
"action": "Created",
"patch": {
"id": "822389184ade4dfb9d3fb0ec38dad11521f2b0d2",
"author": {
"id": "did:key:z6MkkMqyfkMdn8p1LF7LbjjEPJmZGksr3cdpsvFdxKWUVfNZ",
"alias": "kinnison-lassitude"
},
"title": "Enable unseeding by repository name",
"state": {
"status": "draft",
"conflicts": []
},
"before": "ee17109501428319311d18f9bfc339a2a6dec88b",
"after": "d8e5a19cd61da43640b61bb7487ced0f63f0c6f4",
"commits": [
"d8e5a19cd61da43640b61bb7487ced0f63f0c6f4",
"425a97a9191e48fb7417407acb47fe96916fdcb3",
"03327bcdde6017d8af98f0219cdae079031e9498"
],
"target": "71a91042d96bb994c4cd4311d85f5cd1a6311b4e",
"labels": [],
"assignees": [],
"revisions": [
{
"id": "822389184ade4dfb9d3fb0ec38dad11521f2b0d2",
"author": {
"id": "did:key:z6MkkMqyfkMdn8p1LF7LbjjEPJmZGksr3cdpsvFdxKWUVfNZ",
"alias": "kinnison-lassitude"
},
"description": "When I was looking at `rad ls` and wanting to unseed things, I instinctively tried to `rad unseed reponame` which failed because it wasn't a `rid`.\n\nThis patch enables unseeding by repository name, coping with ambiguity by not unseeding anything. Currently ambiguity is listed using `log::error` which by default won't show anything. Perhaps `term::notice!()` might be better?",
"base": "ee17109501428319311d18f9bfc339a2a6dec88b",
"oid": "dc472dd78d1c0bf08c55f7bd8fb532ec3271dfe2",
"timestamp": 1782570441
},
{
"id": "c06577b0490cb11fbbd666afe1371053c53bd515",
"author": {
"id": "did:key:z6MkkMqyfkMdn8p1LF7LbjjEPJmZGksr3cdpsvFdxKWUVfNZ",
"alias": "kinnison-lassitude"
},
"description": "Move name resolution into a trait in the radicle crate.",
"base": "ee17109501428319311d18f9bfc339a2a6dec88b",
"oid": "d8e5a19cd61da43640b61bb7487ced0f63f0c6f4",
"timestamp": 1783445207
}
]
}
}
{
"response": "triggered",
"run_id": {
"id": "4c411001-250d-4d85-9218-b9a054930be4"
},
"info_url": "https://cci.rad.levitte.org//4c411001-250d-4d85-9218-b9a054930be4.html"
}
Started at: 2026-07-27 18:39:08.865066+02:00
Commands:
$ rad clone rad:z3gqcJUoA1n9HaHKufZs5FCSGazv5 .
✓ Creating checkout in ./...
✓ Remote cloudhead@z6MksFqXN3Yhqk8pTJdUGLwATkRfQvwZXPqR2qMEhbS9wzpT added
✓ Remote-tracking branch cloudhead@z6MksFqXN3Yhqk8pTJdUGLwATkRfQvwZXPqR2qMEhbS9wzpT/master created for z6MksFqXN3Yhqk8pTJdUGLwATkRfQvwZXPqR2qMEhbS9wzpT
✓ Remote cloudhead@z6MktaNvN1KVFMkSRAiN4qK5yvX1zuEEaseeX5sffhzPZRZW added
✓ Remote-tracking branch cloudhead@z6MktaNvN1KVFMkSRAiN4qK5yvX1zuEEaseeX5sffhzPZRZW/master created for z6MktaNvN1KVFMkSRAiN4qK5yvX1zuEEaseeX5sffhzPZRZW
✓ Remote fintohaps@z6MkireRatUThvd3qzfKht1S44wpm4FEWSSa4PRMTSQZ3voM added
✓ Remote-tracking branch fintohaps@z6MkireRatUThvd3qzfKht1S44wpm4FEWSSa4PRMTSQZ3voM/master created for z6MkireRatUThvd3qzfKht1S44wpm4FEWSSa4PRMTSQZ3voM
✓ Remote erikli@z6MkgFq6z5fkF2hioLLSNu1zP2qEL1aHXHZzGH1FLFGAnBGz added
✓ Remote-tracking branch erikli@z6MkgFq6z5fkF2hioLLSNu1zP2qEL1aHXHZzGH1FLFGAnBGz/master created for z6MkgFq6z5fkF2hioLLSNu1zP2qEL1aHXHZzGH1FLFGAnBGz
✓ Remote lorenz@z6MkkPvBfjP4bQmco5Dm7UGsX2ruDBieEHi8n9DVJWX5sTEz added
✓ Remote-tracking branch lorenz@z6MkkPvBfjP4bQmco5Dm7UGsX2ruDBieEHi8n9DVJWX5sTEz/master created for z6MkkPvBfjP4bQmco5Dm7UGsX2ruDBieEHi8n9DVJWX5sTEz
✓ Repository successfully cloned under /opt/radcis/ci.rad.levitte.org/cci/state/4c411001-250d-4d85-9218-b9a054930be4/w/
╭────────────────────────────────────╮
│ heartwood │
│ Radicle Heartwood Protocol & Stack │
│ 188 issues · 38 patches │
╰────────────────────────────────────╯
Run `cd ./.` to go to the repository directory.
Exit code: 0
$ rad patch checkout 822389184ade4dfb9d3fb0ec38dad11521f2b0d2
✓ Switched to branch patch/8223891 at revision c06577b
✓ Branch patch/8223891 setup to track rad/patches/822389184ade4dfb9d3fb0ec38dad11521f2b0d2
Exit code: 0
$ git config advice.detachedHead false
Exit code: 0
$ git checkout d8e5a19cd61da43640b61bb7487ced0f63f0c6f4
HEAD is now at d8e5a19c radicle-cli: Enable unseed to use the repo name
Exit code: 0
$ rad patch show 822389184ade4dfb9d3fb0ec38dad11521f2b0d2 -p
╭─────────────────────────────────────────────────────────────────────────────────────────╮
│ Title Enable unseeding by repository name │
│ Patch 822389184ade4dfb9d3fb0ec38dad11521f2b0d2 │
│ Author kinnison-lassitude z6MkkMq…KWUVfNZ │
│ Head d8e5a19cd61da43640b61bb7487ced0f63f0c6f4 │
│ Base ee17109501428319311d18f9bfc339a2a6dec88b │
│ Branches patch/8223891 │
│ Commits ahead 3, behind 86 │
│ Status draft │
│ │
│ When I was looking at `rad ls` and wanting to unseed things, I instinctively │
│ tried to `rad unseed reponame` which failed because it wasn't a `rid`. │
│ │
│ This patch enables unseeding by repository name, coping with ambiguity by not │
│ unseeding anything. Currently ambiguity is listed using `log::error` which by │
│ default won't show anything. Perhaps `term::notice!()` might be better? │
├─────────────────────────────────────────────────────────────────────────────────────────┤
│ d8e5a19 radicle-cli: Enable unseed to use the repo name │
│ 425a97a radicle-cli: Rename delete() in unseed │
│ 03327bc radicle: Add ProjectNameResolver │
├─────────────────────────────────────────────────────────────────────────────────────────┤
│ ● Revision 8223891 @ ee17109..dc472dd by kinnison-lassitude z6MkkMq…KWUVfNZ 4 weeks ago │
│ ↑ Revision c06577b @ ee17109..d8e5a19 by kinnison-lassitude z6MkkMq…KWUVfNZ 2 weeks ago │
╰─────────────────────────────────────────────────────────────────────────────────────────╯
commit d8e5a19cd61da43640b61bb7487ced0f63f0c6f4
Author: Daniel Silverstone <dsilvers@digital-scurf.org>
Date: Sat Jun 27 15:24:00 2026 +0100
radicle-cli: Enable unseed to use the repo name
Enable unseeding by name rather than only by repo id. If the name is
ambiguous then we will not unseed it.
Signed-off-by: Daniel Silverstone <dsilvers@digital-scurf.org>
diff --git a/crates/radicle-cli/src/commands/unseed.rs b/crates/radicle-cli/src/commands/unseed.rs
index 2afd7266d..d40bda315 100644
--- a/crates/radicle-cli/src/commands/unseed.rs
+++ b/crates/radicle-cli/src/commands/unseed.rs
@@ -2,7 +2,7 @@ pub mod args;
use radicle::{Node, prelude::*};
-use crate::terminal as term;
+use crate::{common_args::RidOrName, terminal as term};
pub use args::Args;
@@ -10,7 +10,41 @@ pub fn run(args: Args, ctx: impl term::Context) -> anyhow::Result<()> {
let profile = ctx.profile()?;
let mut node = radicle::Node::new(profile.socket_from_env());
+ let storage = &profile.storage;
+ let policy = profile.policies()?;
+
for rid in args.rids {
+ let rid = match rid {
+ RidOrName::Rid(repo_id) => repo_id,
+ RidOrName::Name(name) => {
+ let repos = storage
+ .resolve_name(&name)?
+ .into_iter()
+ .filter_map(|r| match policy.is_seeding(&r.rid) {
+ Ok(true) => Some(Ok(r)),
+ Ok(false) => None,
+ Err(e) => Some(Err(e)),
+ })
+ .collect::<Result<Vec<_>, _>>()?;
+ if repos.is_empty() {
+ log::warn!(target: "cli", "Unknown repository: {name}");
+ continue;
+ } else if repos.len() > 1 {
+ let ids = {
+ let mut ids = repos.first().expect("There is more than one id").rid.urn();
+ for id in repos.iter().skip(1) {
+ ids.push(' ');
+ ids.push_str(&id.rid.urn());
+ }
+ ids
+ };
+ log::error!(target: "cli", "Ambiguous repository: {name} (maps to: {ids})");
+ continue;
+ } else {
+ repos.first().expect("There is at least one").rid
+ }
+ }
+ };
unseed(rid, &mut node, &profile)?;
}
diff --git a/crates/radicle-cli/src/common_args.rs b/crates/radicle-cli/src/common_args.rs
index 05859de28..64e1cb539 100644
--- a/crates/radicle-cli/src/common_args.rs
+++ b/crates/radicle-cli/src/common_args.rs
@@ -1,6 +1,10 @@
use std::str::FromStr;
-use radicle::storage::refs;
+use radicle::{
+ identity::{doc::RAD_PREFIX, project::ProjectName},
+ prelude::RepoId,
+ storage::refs,
+};
pub const ABOUT_FETCH_SIGNED_REFERENCES_FEATURE_LEVEL_MINIMUM: &str = r#"
Perform the fetch using the provided Signed References minimum feature
@@ -77,3 +81,23 @@ impl clap::builder::TypedValueParser for SignedReferencesFeatureLevelParser {
))
}
}
+
+#[derive(Clone, Debug)]
+pub enum RidOrName {
+ Rid(RepoId),
+ Name(ProjectName),
+}
+
+impl FromStr for RidOrName {
+ type Err = String;
+
+ fn from_str(s: &str) -> Result<Self, Self::Err> {
+ if s.starts_with(RAD_PREFIX) {
+ Ok(Self::Rid(RepoId::from_str(s).map_err(|e| e.to_string())?))
+ } else {
+ Ok(Self::Name(
+ ProjectName::from_str(s).map_err(|e| e.to_string())?,
+ ))
+ }
+ }
+}
commit 425a97a9191e48fb7417407acb47fe96916fdcb3
Author: Daniel Silverstone <dsilvers@digital-scurf.org>
Date: Sat Jun 27 15:05:20 2026 +0100
radicle-cli: Rename delete() in unseed
The unseed CLI command was implemented in a function named `delete`
but it doesn't delete anything, just unseed it.
Signed-off-by: Daniel Silverstone <dsilvers@digital-scurf.org>
diff --git a/crates/radicle-cli/src/commands/unseed.rs b/crates/radicle-cli/src/commands/unseed.rs
index 04a444bc6..2afd7266d 100644
--- a/crates/radicle-cli/src/commands/unseed.rs
+++ b/crates/radicle-cli/src/commands/unseed.rs
@@ -11,13 +11,13 @@ pub fn run(args: Args, ctx: impl term::Context) -> anyhow::Result<()> {
let mut node = radicle::Node::new(profile.socket_from_env());
for rid in args.rids {
- delete(rid, &mut node, &profile)?;
+ unseed(rid, &mut node, &profile)?;
}
Ok(())
}
-pub fn delete(rid: RepoId, node: &mut Node, profile: &Profile) -> anyhow::Result<()> {
+pub fn unseed(rid: RepoId, node: &mut Node, profile: &Profile) -> anyhow::Result<()> {
if profile.unseed(rid, node)? {
term::success!("Seeding policy for {} removed", term::format::tertiary(rid));
}
commit 03327bcdde6017d8af98f0219cdae079031e9498
Author: Daniel Silverstone <dsilvers@digital-scurf.org>
Date: Tue Jul 7 18:20:32 2026 +0100
radicle: Add ProjectNameResolver
Add a mechanism to resolve project names into repository IDs in storages.
The default implementation just iterates through the output of the
ReadStorage::repositories() function, but cleverer storages could cache
or otherwise improve things.
Signed-off-by: Daniel Silverstone <dsilvers@digital-scurf.org>
diff --git a/crates/radicle/src/lib.rs b/crates/radicle/src/lib.rs
index c1ee20251..49895b777 100644
--- a/crates/radicle/src/lib.rs
+++ b/crates/radicle/src/lib.rs
@@ -43,5 +43,8 @@ pub mod prelude {
pub use identity::{Did, Doc, RawDoc, RepoId, project::Project};
pub use node::{Alias, NodeId, Timestamp};
pub use profile::Profile;
- pub use storage::{ReadRepository, ReadStorage, SignRepository, WriteRepository, WriteStorage};
+ pub use storage::{
+ ProjectNameResolver, ReadRepository, ReadStorage, ResolvedRepository, SignRepository,
+ WriteRepository, WriteStorage,
+ };
}
diff --git a/crates/radicle/src/storage.rs b/crates/radicle/src/storage.rs
index 99c99a69c..df7384bf6 100644
--- a/crates/radicle/src/storage.rs
+++ b/crates/radicle/src/storage.rs
@@ -1,5 +1,6 @@
pub mod git;
pub mod refs;
+mod resolver;
use std::collections::{HashSet, hash_map};
use std::ops::Deref;
@@ -13,6 +14,7 @@ use thiserror::Error;
pub use crate::git::Oid;
use crypto::PublicKey;
pub use git::{Validation, Validations};
+pub use resolver::{ProjectNameResolver, ResolvedRepository};
use crate::cob;
use crate::collections::RandomMap;
diff --git a/crates/radicle/src/storage/git.rs b/crates/radicle/src/storage/git.rs
index 56b185435..3b1413157 100644
--- a/crates/radicle/src/storage/git.rs
+++ b/crates/radicle/src/storage/git.rs
@@ -17,6 +17,7 @@ use crate::identity::doc::DocError;
use crate::identity::{Doc, DocAt, RepoId};
use crate::identity::{Identity, Project};
use crate::node::device::Device;
+use crate::prelude::ProjectNameResolver;
use crate::storage::refs::{FeatureLevel, Refs, SignedRefs};
use crate::storage::{
ReadRepository, ReadStorage, Remote, Remotes, RepositoryInfo, SetHead, SignRepository,
@@ -213,6 +214,8 @@ impl WriteStorage for Storage {
}
}
+impl ProjectNameResolver for Storage {}
+
impl Storage {
/// Open a new storage instance and load its inventory.
pub fn open<P: AsRef<Path>>(path: P, info: UserInfo) -> Result<Self, Error> {
diff --git a/crates/radicle/src/storage/resolver.rs b/crates/radicle/src/storage/resolver.rs
new file mode 100644
index 000000000..ef840e79d
--- /dev/null
+++ b/crates/radicle/src/storage/resolver.rs
@@ -0,0 +1,75 @@
+//! Repository resolution
+//!
+//! When a user chooses to name a repository, we retain that and
+//! permit them to look it up by that name later.
+//!
+//! Anything which implements [`ReadStorage`] automatically
+//! implements [`Resolver`] to allow this, though specialisation
+//! is permitted.
+
+use radicle_core::RepoId;
+
+use crate::{identity::project::ProjectName, prelude::ReadStorage};
+
+pub mod error {
+ use radicle_core::RepoId;
+ use thiserror::Error;
+
+ #[derive(Debug, Error)]
+ pub enum FromProjectName {
+ #[error("unable to fetch repositories: {source}")]
+ RepositoryList {
+ source: Box<dyn std::error::Error + Send + Sync + 'static>,
+ },
+ #[error("Unable to retrieve information about RID: '{rid}': {source}")]
+ BadProject {
+ rid: RepoId,
+ source: Box<dyn std::error::Error + Send + Sync + 'static>,
+ },
+ }
+}
+
+/// A repository found in a storage which matches some given name
+pub struct ResolvedRepository {
+ pub name: ProjectName,
+ pub rid: RepoId,
+}
+
+/// The ability to resolve a name into zero or more
+/// possible repositories which the user might have meant.
+pub trait ProjectNameResolver: ReadStorage {
+ /// Look up all the repositories in this [`ReadStorage`] which might
+ /// be referred to by the given name. If the storage has no cache
+ /// and no useful way to filter more efficiently, then the default
+ /// implementation ought to be sufficient.
+ fn resolve_name(
+ &self,
+ project_name: &ProjectName,
+ ) -> Result<Vec<ResolvedRepository>, error::FromProjectName> {
+ let mut ret = Vec::new();
+ for repo in self
+ .repositories()
+ .map_err(|e| error::FromProjectName::RepositoryList {
+ source: Box::new(e),
+ })?
+ {
+ if repo
+ .doc
+ .project()
+ .map_err(|e| error::FromProjectName::BadProject {
+ rid: repo.rid,
+ source: e.into(),
+ })?
+ .name()
+ == project_name.as_str()
+ {
+ ret.push(ResolvedRepository {
+ name: project_name.clone(),
+ rid: repo.rid,
+ });
+ }
+ }
+
+ Ok(ret)
+ }
+}
Exit code: 0
shell: 'export RUSTDOCFLAGS=''-D warnings'' cargo --version rustc --version cargo fmt --check cargo clippy --all-targets --workspace -- --deny warnings cargo build --all-targets --workspace cargo doc --workspace --no-deps --all-features cargo test --workspace --no-fail-fast '
Commands:
$ podman run --name 4c411001-250d-4d85-9218-b9a054930be4 -v /opt/radcis/ci.rad.levitte.org/cci/state/4c411001-250d-4d85-9218-b9a054930be4/s:/4c411001-250d-4d85-9218-b9a054930be4/s:ro -v /opt/radcis/ci.rad.levitte.org/cci/state/4c411001-250d-4d85-9218-b9a054930be4/w:/4c411001-250d-4d85-9218-b9a054930be4/w -w /4c411001-250d-4d85-9218-b9a054930be4/w -v /opt/radcis/ci.rad.levitte.org/.radicle:/${id}/.radicle:ro -e RAD_HOME=/${id}/.radicle rust:trixie bash /4c411001-250d-4d85-9218-b9a054930be4/s/script.sh
+ export 'RUSTDOCFLAGS=-D warnings'
+ RUSTDOCFLAGS='-D warnings'
+ cargo --version
info: syncing channel updates for '1.95-x86_64-unknown-linux-gnu'
info: latest update on 2026-04-16, rust version 1.95.0 (59807616e 2026-04-14)
info: downloading component 'cargo'
info: downloading component 'clippy'
info: downloading component 'rust-docs'
info: downloading component 'rust-src'
info: downloading component 'rust-std'
info: downloading component 'rustc'
info: downloading component 'rustfmt'
info: installing component 'cargo'
info: installing component 'clippy'
info: installing component 'rust-docs'
info: installing component 'rust-src'
info: installing component 'rust-std'
info: installing component 'rustc'
info: installing component 'rustfmt'
cargo 1.95.0 (f2d3ce0bd 2026-03-21)
+ rustc --version
rustc 1.95.0 (59807616e 2026-04-14)
+ cargo fmt --check
+ cargo clippy --all-targets --workspace -- --deny warnings
Updating crates.io index
Downloading crates ...
Downloaded borrow-or-share v0.2.4
Downloaded cipher v0.4.4
Downloaded autocfg v1.5.0
Downloaded data-encoding v2.10.0
Downloaded chacha20 v0.9.1
Downloaded anstream v0.6.21
Downloaded bcrypt-pbkdf v0.10.0
Downloaded clap_derive v4.6.0
Downloaded crypto-common v0.1.7
Downloaded diff v0.1.13
Downloaded bloomy v1.2.0
Downloaded crossbeam-utils v0.8.21
Downloaded colored v2.2.0
Downloaded env_logger v0.11.9
Downloaded base32 v0.4.0
Downloaded ed25519 v2.2.3
Downloaded ecdsa v0.16.9
Downloaded data-encoding-macro v0.1.19
Downloaded chacha20poly1305 v0.10.1
Downloaded erased-serde v0.4.10
Downloaded elliptic-curve v0.13.8
Downloaded ed25519 v1.5.3
Downloaded data-encoding-macro-internal v0.1.17
Downloaded equivalent v1.0.2
Downloaded displaydoc v0.2.5
Downloaded generic-array v0.14.7
Downloaded env_filter v1.0.0
Downloaded escargot v0.5.15
Downloaded ctr v0.9.2
Downloaded crc32fast v1.5.0
Downloaded filetime v0.2.27
Downloaded ghash v0.5.1
Downloaded ed25519-dalek v2.2.0
Downloaded git-ref-format-core v0.6.0
Downloaded getrandom v0.3.4
Downloaded form_urlencoded v1.2.2
Downloaded flate2 v1.1.9
Downloaded fancy-regex v0.14.0
Downloaded gix-date v0.15.3
Downloaded gix-path v0.12.0
Downloaded gix-error v0.2.3
Downloaded gix-quote v0.7.1
Downloaded gix-prompt v0.15.0
Downloaded gix-trace v0.1.19
Downloaded heck v0.5.0
Downloaded gix-fs v0.21.1
Downloaded group v0.13.0
Downloaded idna_adapter v1.2.1
Downloaded gix-validate v0.11.1
Downloaded hash32 v0.3.1
Downloaded gix-url v0.36.0
Downloaded inout v0.1.4
Downloaded human-panic v2.0.6
Downloaded humantime v2.3.0
Downloaded iana-time-zone v0.1.65
Downloaded gix-pack v0.70.0
Downloaded icu_normalizer v2.1.1
Downloaded lazy_static v1.5.0
Downloaded jobserver v0.1.34
Downloaded indexmap v2.13.0
Downloaded maybe-async v0.2.10
Downloaded num-cmp v0.1.0
Downloaded memmap2 v0.9.10
Downloaded num-iter v0.1.45
Downloaded pretty_assertions v1.4.1
Downloaded rand_xorshift v0.4.0
Downloaded pem-rfc7468 v0.7.0
Downloaded log v0.4.29
Downloaded radicle-std-ext v0.2.0
Downloaded polyval v0.6.2
Downloaded radicle-git-ext v0.12.0
Downloaded pbkdf2 v0.12.2
Downloaded memchr v2.8.0
Downloaded rand_chacha v0.3.1
Downloaded phf v0.11.3
Downloaded poly1305 v0.8.0
Downloaded ref-cast-impl v1.0.25
Downloaded rustc_version v0.4.1
Downloaded shell-words v1.1.1
Downloaded salsa20 v0.10.2
Downloaded pin-project-lite v0.2.17
Downloaded scrypt v0.11.0
Downloaded rustc-demangle v0.1.27
Downloaded sem_safe v0.2.1
Downloaded secrecy v0.10.3
Downloaded p521 v0.13.3
Downloaded sha1 v0.10.6
Downloaded siphasher v1.0.2
Downloaded serde_spanned v1.0.4
Downloaded signal-hook v0.3.18
Downloaded socks5-client v0.4.3
Downloaded snapbox-macros v1.1.0
Downloaded schemars v1.2.1
Downloaded spki v0.7.3
Downloaded tree-sitter-css v0.23.2
Downloaded tree-sitter-language v0.1.7
Downloaded tree-sitter-html v0.23.2
Downloaded zerofrom v0.1.6
Downloaded synstructure v0.13.2
Downloaded typeid v1.0.3
Downloaded test-log-macros v0.2.19
Downloaded zerofrom-derive v0.1.6
Downloaded zerovec-derive v0.11.2
Downloaded spin v0.9.8
Downloaded xattr v1.6.1
Downloaded utf8_iter v1.0.4
Downloaded wait-timeout v0.2.1
Downloaded zerotrie v0.2.3
Downloaded zmij v1.0.21
Downloaded writeable v0.6.2
Downloaded zeroize v1.8.2
Downloaded yoke v0.8.1
Downloaded thiserror v2.0.18
Downloaded value-bag v1.12.0
Downloaded uuid v1.22.0
Downloaded sval v2.17.0
Downloaded typenum v1.19.0
Downloaded tree-sitter-go v0.23.4
Downloaded yansi v1.0.1
Downloaded tracing-core v0.1.36
Downloaded ssh-key v0.6.7
Downloaded unicode-segmentation v1.12.0
Downloaded zerovec v0.11.5
Downloaded unicode-normalization v0.1.25
Downloaded toml v0.9.12+spec-1.1.0
Downloaded zlib-rs v0.6.3
Downloaded tree-sitter-python v0.23.6
Downloaded vcpkg v0.2.15
Downloaded object v0.37.3
Downloaded tracing-subscriber v0.3.23
Downloaded zerocopy v0.8.42
Downloaded tree-sitter v0.24.7
Downloaded tree-sitter-md v0.3.2
Downloaded rustix v1.1.4
Downloaded tree-sitter-rust v0.23.3
Downloaded syn v2.0.117
Downloaded syn v1.0.109
Downloaded regex-syntax v0.8.10
Downloaded unicode-width v0.2.2
Downloaded sysinfo v0.37.2
Downloaded tree-sitter-c v0.23.4
Downloaded tinyvec v1.11.0
Downloaded jiff v0.2.23
Downloaded regex-automata v0.4.14
Downloaded tracing v0.1.44
Downloaded tree-sitter-ruby v0.23.1
Downloaded libc v0.2.183
Downloaded tree-sitter-bash v0.23.3
Downloaded thiserror v1.0.69
Downloaded tar v0.4.45
Downloaded libz-sys v1.1.25
Downloaded serde_json v1.0.149
Downloaded unicode-ident v1.0.24
Downloaded tree-sitter-toml-ng v0.6.0
Downloaded tracing-log v0.2.0
Downloaded toml_writer v1.0.7+spec-1.1.0
Downloaded tinystr v0.8.2
Downloaded sha1-checked v0.10.0
Downloaded walkdir v2.5.0
Downloaded tree-sitter-typescript v0.23.2
Downloaded tree-sitter-highlight v0.24.7
Downloaded toml_datetime v0.7.5+spec-1.1.0
Downloaded sha3 v0.10.8
Downloaded universal-hash v0.5.1
Downloaded unarray v0.1.4
Downloaded timeago v0.4.2
Downloaded thread_local v1.1.9
Downloaded tokio v1.50.0
Downloaded url v2.5.8
Downloaded unicode-display-width v0.3.0
Downloaded thiserror-impl v2.0.18
Downloaded vsimd v0.8.0
Downloaded systemd-journal-logger v2.2.2
Downloaded sval_nested v2.17.0
Downloaded unit-prefix v0.5.2
Downloaded tinyvec_macros v0.1.1
Downloaded test-log v0.2.19
Downloaded thiserror-impl v1.0.69
Downloaded tempfile v3.27.0
Downloaded proptest v1.10.0
Downloaded yoke-derive v0.8.1
Downloaded value-bag-sval2 v1.12.0
Downloaded value-bag-serde1 v1.12.0
Downloaded utf8parse v0.2.2
Downloaded version_check v0.9.5
Downloaded uuid-simd v0.8.0
Downloaded sval_buffer v2.17.0
Downloaded structured-logger v1.0.5
Downloaded streaming-iterator v0.1.9
Downloaded ssh-cipher v0.2.0
Downloaded ssh-agent-lib v0.6.0
Downloaded similar v3.1.1
Downloaded errno v0.3.14
Downloaded tree-sitter-json v0.24.8
Downloaded subtle v2.6.1
Downloaded sval_serde v2.17.0
Downloaded sval_ref v2.17.0
Downloaded sval_json v2.17.0
Downloaded sval_fmt v2.17.0
Downloaded sval_dynamic v2.17.0
Downloaded strsim v0.11.1
Downloaded stable_deref_trait v1.2.1
Downloaded ssh-encoding v0.2.0
Downloaded sqlite3-sys v0.18.0
Downloaded sqlite v0.37.0
Downloaded socket2 v0.5.10
Downloaded snapbox v1.2.2
Downloaded smallvec v1.15.1
Downloaded siphasher v0.3.11
Downloaded simd-adler32 v0.3.8
Downloaded signals_receipts v0.2.5
Downloaded signal-hook-registry v1.4.8
Downloaded sharded-slab v0.1.7
Downloaded serde_derive v1.0.228
Downloaded serde v1.0.228
Downloaded regex v1.12.3
Downloaded radicle-surf v0.27.1
Downloaded portable-atomic v1.13.1
Downloaded num-bigint-dig v0.8.6
Downloaded signature v1.6.4
Downloaded shlex v1.3.0
Downloaded sha2 v0.10.9
Downloaded signature v2.2.0
Downloaded signal-hook-mio v0.2.5
Downloaded serde_core v1.0.228
Downloaded p384 v0.13.1
Downloaded serde_fmt v1.1.0
Downloaded rsa v0.9.10
Downloaded serde_derive_internals v0.29.1
Downloaded serde-untagged v0.1.9
Downloaded semver v1.0.27
Downloaded sec1 v0.7.3
Downloaded rand v0.9.2
Downloaded ryu v1.0.23
Downloaded rustversion v1.0.22
Downloaded rand v0.8.5
Downloaded prodash v31.0.0
Downloaded schemars_derive v1.2.1
Downloaded rusty-fork v0.3.1
Downloaded mio v1.1.1
Downloaded referencing v0.30.0
Downloaded rand_core v0.9.5
Downloaded proc-macro2 v1.0.106
Downloaded scopeguard v1.2.0
Downloaded same-file v1.0.6
Downloaded rand_chacha v0.9.0
Downloaded primeorder v0.13.6
Downloaded parking_lot v0.12.5
Downloaded libm v0.2.16
Downloaded ppv-lite86 v0.2.21
Downloaded quick-error v1.2.3
Downloaded qcheck v1.0.0
Downloaded proc-macro-error2 v2.0.1
Downloaded pkcs1 v0.7.5
Downloaded rfc6979 v0.4.0
Downloaded rand_core v0.6.4
Downloaded ref-cast v1.0.25
Downloaded quote v1.0.45
Downloaded qcheck-macros v1.0.0
Downloaded proc-macro-error-attr2 v2.0.0
Downloaded pkg-config v0.3.32
Downloaded pkcs8 v0.10.2
Downloaded num-integer v0.1.46
Downloaded nu-ansi-term v0.50.3
Downloaded num-rational v0.4.2
Downloaded num-bigint v0.4.6
Downloaded itertools v0.14.0
Downloaded potential_utf v0.1.4
Downloaded percent-encoding v2.3.2
Downloaded jsonschema v0.30.0
Downloaded once_cell v1.21.4
Downloaded miniz_oxide v0.8.9
Downloaded pastey v0.2.1
Downloaded num v0.4.3
Downloaded nonempty v0.12.0
Downloaded noise-framework v0.4.1
Downloaded phf_shared v0.11.3
Downloaded parking_lot_core v0.9.12
Downloaded p256 v0.13.2
Downloaded opaque-debug v0.3.1
Downloaded num-traits v0.2.19
Downloaded normalize-line-endings v0.3.0
Downloaded multibase v0.9.2
Downloaded match-lookup v0.1.2
Downloaded litemap v0.8.1
Downloaded outref v0.5.2
Downloaded nonempty v0.9.0
Downloaded indicatif v0.18.4
Downloaded num-complex v0.4.6
Downloaded litrs v1.0.0
Downloaded jiff-static v0.2.23
Downloaded lock_api v0.4.14
Downloaded matchers v0.2.0
Downloaded lexopt v0.3.2
Downloaded icu_properties v2.1.2
Downloaded gimli v0.32.3
Downloaded icu_provider v2.1.1
Downloaded is_terminal_polyfill v1.70.2
Downloaded inquire v0.9.4
Downloaded icu_properties_data v2.1.2
Downloaded git2 v0.20.4
Downloaded keccak v0.1.6
Downloaded itoa v1.0.17
Downloaded idna v1.1.0
Downloaded icu_normalizer_data v2.1.1
Downloaded icu_collections v2.1.1
Downloaded hashbrown v0.16.1
Downloaded gix-transport v0.57.0
Downloaded icu_locale_core v2.1.1
Downloaded heapless v0.8.0
Downloaded hmac v0.12.1
Downloaded gix-revision v0.45.0
Downloaded gix-refspec v0.41.0
Downloaded gix-traverse v0.57.0
Downloaded gix-revwalk v0.31.0
Downloaded gix-ref v0.63.0
Downloaded gix-protocol v0.61.0
Downloaded gix-packetline v0.21.3
Downloaded gix-odb v0.80.0
Downloaded gix-hash v0.25.0
Downloaded gix-tempfile v23.0.0
Downloaded gix-sec v0.14.0
Downloaded gix-utils v0.3.2
Downloaded gix-credentials v0.38.0
Downloaded bstr v1.12.1
Downloaded gix-shallow v0.12.0
Downloaded gix-object v0.60.0
Downloaded gix-lock v23.0.0
Downloaded curve25519-dalek v4.1.3
Downloaded gix-negotiate v0.31.0
Downloaded gix-features v0.48.0
Downloaded gix-glob v0.26.0
Downloaded gix-chunk v0.7.1
Downloaded fraction v0.15.3
Downloaded clap_builder v4.6.0
Downloaded gix-diff v0.63.0
Downloaded getrandom v0.2.17
Downloaded chrono v0.4.44
Downloaded aho-corasick v1.1.4
Downloaded gix-hashtable v0.15.0
Downloaded gix-commitgraph v0.37.0
Downloaded git-ref-format-macro v0.6.0
Downloaded cyphernet v0.5.4
Downloaded gix-config-value v0.18.0
Downloaded gix-command v0.9.0
Downloaded gix-actor v0.41.0
Downloaded git-ref-format v0.6.0
Downloaded getrandom v0.4.2
Downloaded emojis v0.6.4
Downloaded cc v1.2.57
Downloaded aes v0.8.4
Downloaded crossterm v0.29.0
Downloaded find-msvc-tools v0.1.9
Downloaded crypto-bigint v0.5.5
Downloaded arc-swap v1.9.1
Downloaded derive_more-impl v2.1.1
Downloaded derive_more v2.1.1
Downloaded der v0.7.10
Downloaded base64 v0.22.1
Downloaded console v0.16.3
Downloaded bytes v1.11.1
Downloaded faster-hex v0.10.0
Downloaded const-oid v0.9.6
Downloaded clap_complete v4.6.0
Downloaded clap v4.6.0
Downloaded ahash v0.8.12
Downloaded aead v0.5.2
Downloaded fluent-uri v0.3.2
Downloaded fast-glob v0.3.3
Downloaded cbc v0.1.2
Downloaded base64ct v1.8.3
Downloaded amplify_derive v4.0.1
Downloaded addr2line v0.25.1
Downloaded ff v0.13.1
Downloaded bitflags v2.11.0
Downloaded amplify v4.9.0
Downloaded convert_case v0.10.0
Downloaded byteorder v1.5.0
Downloaded bit-vec v0.8.0
Downloaded ascii v1.1.0
Downloaded either v1.15.0
Downloaded ec25519 v0.1.0
Downloaded bytecount v0.6.9
Downloaded backtrace v0.3.76
Downloaded email_address v0.2.9
Downloaded ct-codecs v1.1.6
Downloaded bit-set v0.8.0
Downloaded base256emoji v1.0.2
Downloaded anstyle-parse v1.0.0
Downloaded fnv v1.0.7
Downloaded fastrand v2.3.0
Downloaded dunce v1.0.5
Downloaded digest v0.10.7
Downloaded bytesize v2.3.1
Downloaded block-buffer v0.10.4
Downloaded colorchoice v1.0.5
Downloaded clap_lex v1.1.0
Downloaded curve25519-dalek-derive v0.1.1
Downloaded cfg-if v1.0.4
Downloaded amplify_syn v2.0.1
Downloaded document-features v0.2.12
Downloaded cypheraddr v0.4.1
Downloaded anstyle-query v1.1.5
Downloaded dyn-clone v1.0.20
Downloaded cyphergraphy v0.3.1
Downloaded crossbeam-channel v0.5.15
Downloaded cpufeatures v0.2.17
Downloaded base16ct v0.2.0
Downloaded blowfish v0.9.1
Downloaded base-x v0.2.11
Downloaded const-str v0.4.3
Downloaded anyhow v1.0.102
Downloaded block-padding v0.3.3
Downloaded aes-gcm v0.10.3
Downloaded anstyle-parse v0.2.7
Downloaded anstyle v1.0.14
Downloaded adler2 v2.0.1
Downloaded base64 v0.21.7
Downloaded anstream v1.0.0
Downloaded amplify_num v0.5.3
Downloaded libgit2-sys v0.18.3+1.9.2
Downloaded sqlite3-src v0.7.0
Downloaded linux-raw-sys v0.12.1
Compiling libc v0.2.183
Compiling proc-macro2 v1.0.106
Compiling quote v1.0.45
Compiling unicode-ident v1.0.24
Checking cfg-if v1.0.4
Checking zeroize v1.8.2
Compiling version_check v0.9.5
Compiling typenum v1.19.0
Compiling generic-array v0.14.7
Compiling syn v2.0.117
Checking getrandom v0.2.17
Checking rand_core v0.6.4
Checking memchr v2.8.0
Compiling shlex v1.3.0
Compiling jobserver v0.1.34
Compiling find-msvc-tools v0.1.9
Checking crypto-common v0.1.7
Compiling cc v1.2.57
Checking subtle v2.6.1
Compiling serde_core v1.0.228
Checking regex-syntax v0.8.10
Checking aho-corasick v1.1.4
Checking const-oid v0.9.6
Checking smallvec v1.15.1
Checking block-buffer v0.10.4
Checking digest v0.10.7
Checking cpufeatures v0.2.17
Checking stable_deref_trait v1.2.1
Checking regex-automata v0.4.14
Compiling thiserror v2.0.18
Checking fastrand v2.3.0
Compiling parking_lot_core v0.9.12
Checking scopeguard v1.2.0
Checking lock_api v0.4.14
Checking bitflags v2.11.0
Checking parking_lot v0.12.5
Compiling typeid v1.0.3
Compiling erased-serde v0.4.10
Checking tinyvec_macros v0.1.1
Checking gix-trace v0.1.19
Compiling crc32fast v1.5.0
Checking tinyvec v1.11.0
Compiling serde v1.0.228
Checking unicode-normalization v0.1.25
Compiling thiserror-impl v2.0.18
Compiling serde_derive v1.0.228
Checking itoa v1.0.17
Checking bstr v1.12.1
Checking byteorder v1.5.0
Checking gix-utils v0.3.2
Checking gix-validate v0.11.1
Checking serde_fmt v1.1.0
Checking hashbrown v0.16.1
Checking value-bag-serde1 v1.12.0
Compiling synstructure v0.13.2
Checking gix-path v0.12.0
Checking value-bag v1.12.0
Checking same-file v1.0.6
Compiling zerofrom-derive v0.1.6
Checking walkdir v2.5.0
Checking log v0.4.29
Compiling yoke-derive v0.8.1
Checking prodash v31.0.0
Checking zlib-rs v0.6.3
Compiling pkg-config v0.3.32
Checking zerofrom v0.1.6
Checking yoke v0.8.1
Compiling heapless v0.8.0
Compiling rustix v1.1.4
Checking hash32 v0.3.1
Compiling zerovec-derive v0.11.2
Checking gix-features v0.48.0
Compiling libm v0.2.16
Checking linux-raw-sys v0.12.1
Compiling autocfg v1.5.0
Compiling num-traits v0.2.19
Compiling displaydoc v0.2.5
Compiling getrandom v0.4.2
Checking faster-hex v0.10.0
Checking zerovec v0.11.5
Checking block-padding v0.3.3
Compiling zerocopy v0.8.42
Checking inout v0.1.4
Checking sha2 v0.10.9
Checking sha1 v0.10.6
Checking sha1-checked v0.10.0
Checking cipher v0.4.4
Checking tinystr v0.8.2
Checking writeable v0.6.2
Checking percent-encoding v2.3.2
Checking litemap v0.8.1
Checking once_cell v1.21.4
Checking icu_locale_core v2.1.1
Checking gix-hash v0.25.0
Checking potential_utf v0.1.4
Checking zerotrie v0.2.3
Compiling zmij v1.0.21
Compiling icu_properties_data v2.1.2
Compiling icu_normalizer_data v2.1.1
Checking icu_provider v2.1.1
Checking icu_collections v2.1.1
Checking der v0.7.10
Compiling serde_json v1.0.149
Checking equivalent v1.0.2
Checking indexmap v2.13.0
Compiling ref-cast v1.0.25
Compiling vcpkg v0.2.15
Compiling syn v1.0.109
Compiling thiserror v1.0.69
Checking icu_properties v2.1.2
Compiling libz-sys v1.1.25
Checking ppv-lite86 v0.2.21
Checking icu_normalizer v2.1.1
Checking tempfile v3.27.0
Compiling ref-cast-impl v1.0.25
Compiling thiserror-impl v1.0.69
Checking spin v0.9.8
Checking idna_adapter v1.2.1
Checking lazy_static v1.5.0
Checking num-integer v0.1.46
Checking hmac v0.12.1
Checking universal-hash v0.5.1
Checking utf8_iter v1.0.4
Compiling tree-sitter-language v0.1.7
Checking dyn-clone v1.0.20
Checking opaque-debug v0.3.1
Checking idna v1.1.0
Checking spki v0.7.3
Compiling libgit2-sys v0.18.3+1.9.2
Checking signature v2.2.0
Checking ff v0.13.1
Checking base16ct v0.2.0
Checking group v0.13.0
Checking sec1 v0.7.3
Checking rand_chacha v0.3.1
Checking form_urlencoded v1.2.2
Compiling serde_derive_internals v0.29.1
Checking crypto-bigint v0.5.5
Compiling schemars_derive v1.2.1
Checking elliptic-curve v0.13.8
Compiling amplify_syn v2.0.1
Checking url v2.5.8
Checking rand v0.8.5
Checking num-iter v0.1.45
Checking aead v0.5.2
Checking signature v1.6.4
Compiling semver v1.0.27
Checking ed25519 v1.5.3
Compiling amplify_derive v4.0.1
Compiling rustc_version v0.4.1
Checking schemars v1.2.1
Checking poly1305 v0.8.0
Checking rfc6979 v0.4.0
Checking chacha20 v0.9.1
Checking ct-codecs v1.1.6
Checking ascii v1.1.0
Checking amplify_num v0.5.3
Checking ec25519 v0.1.0
Checking ecdsa v0.16.9
Compiling curve25519-dalek v4.1.3
Checking git-ref-format-core v0.6.0
Checking primeorder v0.13.6
Checking polyval v0.6.2
Checking amplify v4.9.0
Compiling num-bigint-dig v0.8.6
Checking base64ct v1.8.3
Checking ghash v0.5.1
Checking pem-rfc7468 v0.7.0
Checking cyphergraphy v0.3.1
Checking pkcs8 v0.10.2
Checking pbkdf2 v0.12.2
Checking aes v0.8.4
Checking ctr v0.9.2
Compiling sqlite3-src v0.7.0
Checking gix-error v0.2.3
Compiling curve25519-dalek-derive v0.1.1
Checking keccak v0.1.6
Checking aes-gcm v0.10.3
Checking sha3 v0.10.8
Checking pkcs1 v0.7.5
Checking ssh-encoding v0.2.0
Checking ed25519 v2.2.3
Checking blowfish v0.9.1
Checking cbc v0.1.2
Checking base32 v0.4.0
Compiling crossbeam-utils v0.8.21
Compiling data-encoding v2.10.0
Checking rsa v0.9.10
Checking cypheraddr v0.4.1
Compiling data-encoding-macro-internal v0.1.17
Checking ssh-cipher v0.2.0
Checking bcrypt-pbkdf v0.10.0
Checking ed25519-dalek v2.2.0
Checking p384 v0.13.1
Checking p521 v0.13.3
Checking p256 v0.13.2
Checking chacha20poly1305 v0.10.1
Checking qcheck v1.0.0
Compiling match-lookup v0.1.2
Checking const-str v0.4.3
Checking data-encoding-macro v0.1.19
Checking base256emoji v1.0.2
Checking ssh-key v0.6.7
Checking noise-framework v0.4.1
Checking socks5-client v0.4.3
Checking secrecy v0.10.3
Checking base-x v0.2.11
Checking ssh-agent-lib v0.6.0
Checking multibase v0.9.2
Checking crossbeam-channel v0.5.15
Checking cyphernet v0.5.4
Checking anstyle-query v1.1.5
Checking errno v0.3.14
Checking jiff v0.2.23
Checking utf8parse v0.2.2
Checking nonempty v0.9.0
Checking siphasher v1.0.2
Checking radicle-localtime v0.1.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-localtime)
Checking radicle-git-metadata v0.2.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-git-metadata)
Checking radicle-dag v0.10.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-dag)
Checking colorchoice v1.0.5
Checking anstyle v1.0.14
Checking is_terminal_polyfill v1.70.2
Checking radicle-git-ref-format v0.1.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-git-ref-format)
Checking gix-hashtable v0.15.0
Compiling signal-hook v0.3.18
Compiling unicode-segmentation v1.12.0
Compiling radicle v0.24.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle)
Checking base64 v0.21.7
Compiling convert_case v0.10.0
Checking gix-date v0.15.3
Checking gix-actor v0.41.0
Checking signal-hook-registry v1.4.8
Checking gix-object v0.60.0
Checking serde-untagged v0.1.9
Checking bytesize v2.3.1
Checking memmap2 v0.9.10
Checking dunce v1.0.5
Checking nonempty v0.12.0
Checking fast-glob v0.3.3
Compiling derive_more-impl v2.1.1
Checking gix-chunk v0.7.1
Checking mio v1.1.1
Checking regex v1.12.3
Checking sem_safe v0.2.1
Compiling litrs v1.0.0
Compiling portable-atomic v1.13.1
Checking unicode-width v0.2.2
Compiling document-features v0.2.12
Checking signals_receipts v0.2.5
Checking derive_more v2.1.1
Checking signal-hook-mio v0.2.5
Checking gix-commitgraph v0.37.0
Checking anstyle-parse v1.0.0
Checking gix-revwalk v0.31.0
Checking anstream v1.0.0
Checking crossterm v0.29.0
Checking console v0.16.3
Checking gix-fs v0.21.1
Checking unit-prefix v0.5.2
Checking gix-tempfile v23.0.0
Checking indicatif v0.18.4
Checking inquire v0.9.4
Checking unicode-display-width v0.3.0
Checking radicle-signals v0.11.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-signals)
Checking gix-quote v0.7.1
Checking iana-time-zone v0.1.65
Checking shell-words v1.1.1
Checking either v1.15.0
Checking gix-command v0.9.0
Checking chrono v0.4.44
Checking colored v2.2.0
Compiling object v0.37.3
Compiling rustversion v1.0.22
Checking gix-lock v23.0.0
Checking gix-url v0.36.0
Checking gix-config-value v0.18.0
Checking gix-sec v0.14.0
Checking adler2 v2.0.1
Checking gimli v0.32.3
Checking miniz_oxide v0.8.9
Checking gix-prompt v0.15.0
Checking addr2line v0.25.1
Checking gix-traverse v0.57.0
Checking gix-revision v0.45.0
Checking gix-diff v0.63.0
Checking anstyle-parse v0.2.7
Checking gix-packetline v0.21.3
Checking gix-glob v0.26.0
Compiling tree-sitter v0.24.7
Checking rustc-demangle v0.1.27
Compiling anyhow v1.0.102
Checking backtrace v0.3.76
Checking gix-refspec v0.41.0
Checking gix-transport v0.57.0
Checking anstream v0.6.21
Checking gix-pack v0.70.0
Checking arc-swap v1.9.1
Checking gix-credentials v0.38.0
Checking gix-ref v0.63.0
Checking gix-shallow v0.12.0
Checking gix-negotiate v0.31.0
Compiling maybe-async v0.2.10
Compiling proc-macro-error-attr2 v2.0.0
Compiling getrandom v0.3.4
Compiling simd-adler32 v0.3.8
Checking gix-protocol v0.61.0
Compiling proc-macro-error2 v2.0.1
Checking gix-odb v0.80.0
Compiling xattr v1.6.1
Compiling filetime v0.2.27
Checking uuid v1.22.0
Checking bytes v1.11.1
Compiling flate2 v1.1.9
Compiling tar v0.4.45
Compiling git-ref-format-macro v0.6.0
Checking snapbox-macros v1.1.0
Checking salsa20 v0.10.2
Checking clap_lex v1.1.0
Checking siphasher v0.3.11
Checking similar v3.1.1
Compiling heck v0.5.0
Checking normalize-line-endings v0.3.0
Checking strsim v0.11.1
Checking streaming-iterator v0.1.9
Checking snapbox v1.2.2
Checking clap_builder v4.6.0
Compiling clap_derive v4.6.0
Checking bloomy v1.2.0
Checking scrypt v0.11.0
Compiling radicle-surf v0.27.1
Checking git-ref-format v0.6.0
Checking systemd-journal-logger v2.2.2
Checking serde_spanned v1.0.4
Checking toml_datetime v0.7.5+spec-1.1.0
Compiling tree-sitter-rust v0.23.3
Compiling tree-sitter-html v0.23.2
Compiling tree-sitter-python v0.23.6
Compiling tree-sitter-go v0.23.4
Compiling tree-sitter-css v0.23.2
Compiling tree-sitter-bash v0.23.3
Compiling tree-sitter-ruby v0.23.1
Checking sqlite3-sys v0.18.0
Compiling tree-sitter-c v0.23.4
Compiling tree-sitter-md v0.3.2
Checking sqlite v0.37.0
Compiling tree-sitter-toml-ng v0.6.0
Compiling tree-sitter-typescript v0.23.2
Compiling tree-sitter-json v0.24.8
Checking radicle-crypto v0.17.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-crypto)
Checking radicle-std-ext v0.2.0
Checking pin-project-lite v0.2.17
Checking toml_writer v1.0.7+spec-1.1.0
Checking tokio v1.50.0
Checking toml v0.9.12+spec-1.1.0
Checking clap v4.6.0
Checking sysinfo v0.37.2
Checking yansi v1.0.1
Compiling radicle-node v0.20.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-node)
Compiling radicle-cli v0.21.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-cli)
Checking diff v0.1.13
Checking pretty_assertions v1.4.1
Checking human-panic v2.0.6
Checking clap_complete v4.6.0
Checking structured-logger v1.0.5
Checking radicle-systemd v0.13.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-systemd)
Checking tree-sitter-highlight v0.24.7
Checking itertools v0.14.0
Compiling qcheck-macros v1.0.0
Checking socket2 v0.5.10
Checking lexopt v0.3.2
Checking timeago v0.4.2
Compiling escargot v0.5.15
Checking humantime v2.3.0
Checking bit-vec v0.8.0
Checking bit-set v0.8.0
Checking rand_core v0.9.5
Checking num-bigint v0.4.6
Compiling ahash v0.8.12
Checking num-complex v0.4.6
Checking env_filter v1.0.0
Checking borrow-or-share v0.2.4
Checking fluent-uri v0.3.2
Checking env_logger v0.11.9
Checking phf_shared v0.11.3
Checking num-rational v0.4.2
Compiling test-log-macros v0.2.19
Checking wait-timeout v0.2.1
Compiling radicle-remote-helper v0.17.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-remote-helper)
Checking num v0.4.3
Checking fnv v1.0.7
Checking outref v0.5.2
Checking quick-error v1.2.3
Checking vsimd v0.8.0
Checking rusty-fork v0.3.1
Checking test-log v0.2.19
Checking fraction v0.15.3
Checking phf v0.11.3
Checking uuid-simd v0.8.0
Checking referencing v0.30.0
Checking rand v0.9.2
Checking rand_xorshift v0.4.0
Checking rand_chacha v0.9.0
Checking fancy-regex v0.14.0
Checking email_address v0.2.9
Checking unarray v0.1.4
Checking num-cmp v0.1.0
Checking base64 v0.22.1
Checking bytecount v0.6.9
Checking proptest v1.10.0
Checking emojis v0.6.4
Checking jsonschema v0.30.0
Compiling pastey v0.2.1
Checking radicle-windows v0.1.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-windows)
Checking git2 v0.20.4
Checking radicle-oid v0.2.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-oid)
Checking radicle-term v0.18.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-term)
Checking radicle-git-ext v0.12.0
Checking radicle-cob v0.20.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-cob)
Checking radicle-core v0.3.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-core)
Checking radicle-log v0.1.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-log)
Checking radicle-fetch v0.20.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-fetch)
Checking radicle-cli-test v0.13.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-cli-test)
Checking radicle-protocol v0.8.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-protocol)
Checking radicle-schemars v0.8.0 (/4c411001-250d-4d85-9218-b9a054930be4/w/crates/radicle-schemars)
Finished `dev` profile [unoptimized + debuginfo] target(s) in 46.92s
+ cargo build --all-targets --workspace
Compiling libc v0.2.183
Compiling cfg-if v1.0.4
Compiling zeroize v1.8.2
Compiling typenum v1.19.0
Compiling memchr v2.8.0
Compiling shlex v1.3.0
Compiling subtle v2.6.1
Compiling regex-syntax v0.8.10
Compiling generic-array v0.14.7
Compiling getrandom v0.2.17
Compiling jobserver v0.1.34
Compiling rand_core v0.6.4
Compiling crypto-common v0.1.7
Compiling cc v1.2.57
Compiling aho-corasick v1.1.4
Compiling serde_core v1.0.228
Compiling const-oid v0.9.6
Compiling regex-automata v0.4.14
Compiling smallvec v1.15.1
Compiling block-buffer v0.10.4
Compiling digest v0.10.7
Compiling cpufeatures v0.2.17
Compiling stable_deref_trait v1.2.1
Compiling bitflags v2.11.0
Compiling fastrand v2.3.0
Compiling thiserror v2.0.18
Compiling scopeguard v1.2.0
Compiling parking_lot_core v0.9.12
Compiling tinyvec_macros v0.1.1
Compiling lock_api v0.4.14
Compiling gix-trace v0.1.19
Compiling tinyvec v1.11.0
Compiling parking_lot v0.12.5
Compiling typeid v1.0.3
Compiling erased-serde v0.4.10
Compiling unicode-normalization v0.1.25
Compiling byteorder v1.5.0
Compiling itoa v1.0.17
Compiling serde v1.0.228
Compiling gix-utils v0.3.2
Compiling crc32fast v1.5.0
Compiling serde_fmt v1.1.0
Compiling hashbrown v0.16.1
Compiling value-bag-serde1 v1.12.0
Compiling value-bag v1.12.0
Compiling same-file v1.0.6
Compiling walkdir v2.5.0
Compiling bstr v1.12.1
Compiling log v0.4.29
Compiling zerofrom v0.1.6
Compiling prodash v31.0.0
Compiling zlib-rs v0.6.3
Compiling gix-validate v0.11.1
Compiling gix-path v0.12.0
Compiling yoke v0.8.1
Compiling hash32 v0.3.1
Compiling linux-raw-sys v0.12.1
Compiling zerovec v0.11.5
Compiling heapless v0.8.0
Compiling faster-hex v0.10.0
Compiling rustix v1.1.4
Compiling libm v0.2.16
Compiling block-padding v0.3.3
Compiling inout v0.1.4
Compiling getrandom v0.4.2
Compiling sha2 v0.10.9
Compiling num-traits v0.2.19
Compiling sha1 v0.10.6
Compiling sha1-checked v0.10.0
Compiling cipher v0.4.4
Compiling zerocopy v0.8.42
Compiling tinystr v0.8.2
Compiling writeable v0.6.2
Compiling once_cell v1.21.4
Compiling percent-encoding v2.3.2
Compiling litemap v0.8.1
Compiling gix-features v0.48.0
Compiling gix-hash v0.25.0
Compiling icu_locale_core v2.1.1
Compiling zerotrie v0.2.3
Compiling potential_utf v0.1.4
Compiling icu_collections v2.1.1
Compiling der v0.7.10
Compiling icu_provider v2.1.1
Compiling equivalent v1.0.2
Compiling zmij v1.0.21
Compiling indexmap v2.13.0
Compiling icu_properties_data v2.1.2
Compiling icu_normalizer_data v2.1.1
Compiling libz-sys v1.1.25
Compiling icu_normalizer v2.1.1
Compiling icu_properties v2.1.2
Compiling serde_json v1.0.149
Compiling ppv-lite86 v0.2.21
Compiling tempfile v3.27.0
Compiling spin v0.9.8
Compiling lazy_static v1.5.0
Compiling ref-cast v1.0.25
Compiling idna_adapter v1.2.1
Compiling num-integer v0.1.46
Compiling hmac v0.12.1
Compiling universal-hash v0.5.1
Compiling opaque-debug v0.3.1
Compiling dyn-clone v1.0.20
Compiling utf8_iter v1.0.4
Compiling thiserror v1.0.69
Compiling spki v0.7.3
Compiling libgit2-sys v0.18.3+1.9.2
Compiling idna v1.1.0
Compiling signature v2.2.0
Compiling ff v0.13.1
Compiling base16ct v0.2.0
Compiling sec1 v0.7.3
Compiling group v0.13.0
Compiling rand_chacha v0.3.1
Compiling form_urlencoded v1.2.2
Terminated
Exit code: 143
{
"response": "finished",
"result": "failure"
}
diff --git a/crates/radicle-cli/src/commands/unseed/args.rs b/crates/radicle-cli/src/commands/unseed/args.rs
index 2c5792667..330a38592 100644
--- a/crates/radicle-cli/src/commands/unseed/args.rs
+++ b/crates/radicle-cli/src/commands/unseed/args.rs
@@ -1,5 +1,6 @@
use clap::Parser;
-use radicle::prelude::RepoId;
+
+use crate::common_args::RidOrName;
const ABOUT: &str = "Remove repository seeding policies";
@@ -10,7 +11,7 @@ for the given repositories."#;
#[derive(Debug, Parser)]
#[command(about = ABOUT, long_about = LONG_ABOUT, disable_version_flag = true)]
pub struct Args {
- /// ID of the repository to remove the seeding policy for (may be repeated)
- #[arg(value_name = "RID", required = true, action = clap::ArgAction::Append)]
- pub rids: Vec<RepoId>,
+ /// ID (or name) of the repository to remove the seeding policy for (may be repeated)
+ #[arg(value_name = "RIDORNAME", required = true, action = clap::ArgAction::Append)]
+ pub rids: Vec<RidOrName>,
}